@@ -2,7 +2,7 @@
  * fo-area-table-part.c: Area object for table-part formatting objects
  *
  * Copyright (C) 2001 Sun Microsystems
- * Copyright (C) 2007 Menteith Consulting Ltd
+ * Copyright (C) 2007-2008 Menteith Consulting Ltd
  *
  * See COPYING for the status of this software.
  */
@@ -11,7 +11,7 @@
 #define __FO_AREA_TABLE_PART_H__
 
 #include <libfo/fo-utils.h>
-#include <area/fo-area-area.h>
+#include <libfo/area/fo-area.h>
 
 G_BEGIN_DECLS
 
