@@ -10,7 +10,8 @@
 #ifndef __FO_AREA_TABLE_PRIVATE_H__
 #define __FO_AREA_TABLE_PRIVATE_H__
 
-#include <libfo/area/fo-area-reference-private.h>
+#include "area/fo-area-table.h"
+#include "area/fo-area-reference-private.h"
 
 G_BEGIN_DECLS
 
