@@ -2,7 +2,7 @@
  * fo-area.c: Base area object of area object system
  *
  * Copyright (C) 2001 Sun Microsystems
- * Copyright (C) 2007 Menteith Consulting Ltd
+ * Copyright (C) 2007-2009 Menteith Consulting Ltd
  *
  * See COPYING for the status of this software.
  */
@@ -922,11 +922,13 @@ fo_area_debug_dump (FoObject *object,
 
 /**
  * fo_area_sprintf:
- * @object: 
+ * @object: #FoArea to print
  * 
+ * Returns a string name of the object type of #object.
+ *
+ * String must be freed by caller.
  * 
- * 
- * Return value: 
+ * Return value: String value of @object.
  **/
 gchar*
 fo_area_sprintf (FoObject *object)
@@ -1543,9 +1545,11 @@ fo_area_break_resolve (FoArea *parent_area,
       fo_area_dump_path_to_root (clone);
 
       /*
-      parent_area = fo_add_to_new_page_area (fo_node, parent_area,
-						 context, NULL,
-						 debug_level);
+      parent_area = fo_add_to_new_page_area (fo_node,
+					     parent_area,
+					     context,
+					     NULL,
+					     debug_level);
       page_number =
 	fo_area_page_get_page_number (parent_area->page);
 
