@@ -22,6 +22,13 @@
 #include "datatype/fo-color.h"
 #include <string.h>
 
+/**
+ * SECTION:fo-doc-gp
+ * @short_description: GNOME Print backend
+ *
+ * GNOME Print backend.
+ */
+
 const char *fo_doc_gp_error_messages [] = {
   N_("FoDocGP error"),
   N_("Cannot open output document: '%s'")
@@ -32,6 +39,8 @@ static void fo_doc_gp_base_init     (FoDocGPClass *klass);
 static void fo_doc_gp_class_init    (FoDocGPClass *klass);
 static void fo_doc_gp_finalize      (GObject      *object);
 
+static const LibfoVersionInfo * _version_info ();
+
 static FoLayout *    fo_doc_gp_get_new_layout   (FoDoc        *fo_doc);
 
 static void          fo_doc_gp_begin_page       (FoDoc        *fo_doc,
@@ -102,6 +111,17 @@ static void 	     fo_doc_gp_render_layout       (FoDoc   *fo_doc,
 						    gdouble   y);
 static gpointer parent_class;
 
+static const LibfoVersionInfo version_info =
+  {
+    LIBFO_MODULE_BACKEND,
+    "gp",
+    "FoDocGP",
+    0,
+    NULL,
+    0,
+    NULL
+  };
+
 /**
  * fo_doc_gp_error_quark:
  * 
@@ -224,8 +244,17 @@ fo_doc_gp_init (FoDocGP *fo_doc_gp)
 void
 fo_doc_gp_base_init (FoDocGPClass *klass)
 {
+  FoLibfoModuleClass *fo_libfo_module_class =
+    FO_LIBFO_MODULE_CLASS (klass);
   FoDocClass *fo_doc_class = FO_DOC_CLASS (klass);
 
+  fo_libfo_module_class->version_info = _version_info;
+
+  fo_doc_class->formats =
+    FO_FLAG_FORMAT_PDF |
+    FO_FLAG_FORMAT_POSTSCRIPT |
+    FO_FLAG_FORMAT_SVG;
+
   fo_doc_class->open_file        = fo_doc_gp_open_file;
 
   fo_doc_class->get_new_layout   = fo_doc_gp_get_new_layout;
@@ -288,21 +317,25 @@ fo_doc_gp_finalize (GObject *object)
 
   fo_doc_gp = FO_DOC_GP (object);
 
-  if (gnome_print_job_print_to_file (fo_doc_gp->job,
-				     fo_doc_gp->current_filename)
+  if ((fo_doc_gp->current_filename != NULL) &&
+      (gnome_print_job_print_to_file (fo_doc_gp->job,
+				      fo_doc_gp->current_filename))
       != GNOME_PRINT_OK)
     {
       g_error ("print_job_print_to_file");
     }
 
-  if (gnome_print_job_close (fo_doc_gp->job) != GNOME_PRINT_OK)
+  if (fo_doc_gp->job != NULL)
     {
-      g_error ("gnome_print_job_close");
-    }
+      if (gnome_print_job_close (fo_doc_gp->job) != GNOME_PRINT_OK)
+	{
+	  g_error ("gnome_print_job_close");
+	}
 
-  if (gnome_print_job_print (fo_doc_gp->job) != GNOME_PRINT_OK)
-    {
-      g_error ("gnome_print_job_print");
+      if (gnome_print_job_print (fo_doc_gp->job) != GNOME_PRINT_OK)
+	{
+	  g_error ("gnome_print_job_print");
+	}
     }
 
   if (fo_doc_gp->base_filename != NULL)
@@ -347,6 +380,12 @@ fo_doc_gp_new (void)
 			       NULL));
 }
 
+const LibfoVersionInfo *
+_version_info ()
+{
+  return &version_info;
+}
+
 /**
  * fo_doc_gp_get_context:
  * @fo_doc: #FoDoc
@@ -463,7 +502,7 @@ fo_doc_gp_begin_page (FoDoc  *fo_doc,
 	}
 
       // FIXME: There has to be a better way to do this.
-      if (fo_doc_gp->format == FO_ENUM_FORMAT_AUTO)
+      if (fo_doc_gp->format == FO_FLAG_FORMAT_AUTO)
 	{
 	  gint len = strlen (fo_doc_gp->base_filename);
 	  if (g_ascii_strncasecmp (&(fo_doc_gp->base_filename)[len-4], ".pdf", 4) == 0)
@@ -487,7 +526,7 @@ fo_doc_gp_begin_page (FoDoc  *fo_doc,
 		}
 	    }
 	}
-      else if (fo_doc_gp->format == FO_ENUM_FORMAT_PDF)
+      else if (fo_doc_gp->format == FO_FLAG_FORMAT_PDF)
 	{
 	  if (!gnome_print_config_set (fo_doc_gp->config,
 				       (guchar *) "Printer",
@@ -496,7 +535,7 @@ fo_doc_gp_begin_page (FoDoc  *fo_doc,
 	      fprintf (stderr, "gnome_print_config_set Printer-PDF");
 	    }
 	}
-      else if (fo_doc_gp->format == FO_ENUM_FORMAT_POSTSCRIPT)
+      else if (fo_doc_gp->format == FO_FLAG_FORMAT_POSTSCRIPT)
 	{
 	  if (!gnome_print_config_set (fo_doc_gp->config,
 				       (guchar *) "Printer",
@@ -506,7 +545,7 @@ fo_doc_gp_begin_page (FoDoc  *fo_doc,
 		       "gnome_print_config_set Printer-POSTSCRIPT");
 	    }
 	}
-      else if (fo_doc_gp->format == FO_ENUM_FORMAT_SVG)
+      else if (fo_doc_gp->format == FO_FLAG_FORMAT_SVG)
 	{
 	  if (!gnome_print_config_set (fo_doc_gp->config,
 				       (guchar *) "Settings.Engine.Backend.Driver",
