@@ -84,7 +84,7 @@ fo_list_item_label_get_type (void)
       };
 
       object_type = g_type_register_static (FO_TYPE_MARKER_PARENT,
-                                            "list-item-label",
+                                            "FoListItemLabel",
                                             &object_info, 0);
     }
 
@@ -114,7 +114,6 @@ fo_list_item_label_class_init (FoListItemLabelClass *klass)
   fofo_class->validate2 = fo_list_item_label_validate;
   fofo_class->update_from_context = fo_list_item_label_update_from_context;
   fofo_class->debug_dump_properties = fo_list_item_label_debug_dump_properties;
-  fofo_class->area_new = fo_list_item_label_area_new;
   fofo_class->area_new2 = fo_list_item_label_area_new2;
 
   g_object_class_install_property
@@ -316,7 +315,7 @@ gboolean
 fo_list_item_label_validate_content (FoFo    *fo,
                                      GError **error)
 {
-  GError *tmp_error;
+  /*GError *tmp_error;*/
 
   g_return_val_if_fail (fo != NULL, TRUE);
   g_return_val_if_fail (FO_IS_LIST_ITEM_LABEL (fo), TRUE);
