@@ -100,7 +100,7 @@ fo_simple_page_master_get_type (void)
       };
 
       object_type = g_type_register_static (FO_TYPE_FO,
-                                            "simple-page-master",
+                                            "FoSimplePageMaster",
                                             &object_info, 0);
     }
 
@@ -414,8 +414,8 @@ fo_simple_page_master_new (void)
  **/
 static void
 fo_simple_page_master_free_hash_key (gpointer key,
-				     gpointer value,
-				     gpointer user_data)
+				     gpointer value G_GNUC_UNUSED,
+				     gpointer user_data G_GNUC_UNUSED)
 {
   g_free (key);
 }
@@ -646,6 +646,7 @@ fo_simple_page_master_validate (FoFo      *fo,
       g_print ("Master name: %s\n", master_name);
       */
       fo_tree_master_name_add (tree, master_name, fo);
+      g_free (master_name);
     }
   else
     {
