@@ -157,7 +157,7 @@ fo_title_get_type (void)
       };
 
       object_type = g_type_register_static (FO_TYPE_FO,
-                                            "title",
+                                            "FoTitle",
                                             &object_info, 0);
     }
 
@@ -935,7 +935,7 @@ gboolean
 fo_title_validate_content (FoFo    *fo,
                            GError **error)
 {
-  GError *tmp_error;
+  /*GError *tmp_error;*/
 
   g_return_val_if_fail (fo != NULL, TRUE);
   g_return_val_if_fail (FO_IS_TITLE (fo), TRUE);
