@@ -2,7 +2,7 @@
  * fo-wrapper-block-area.c: Generate area for wrapper-block formatting object
  *
  * Copyright (C) 2001 Sun Microsystems
- * Copyright (C) 2007 Menteith Consulting Ltd
+ * Copyright (C) 2007-2009 Menteith Consulting Ltd
  *
  * !See COPYING for the status of this software.
  */
@@ -36,7 +36,7 @@ fo_wrapper_block_area_new2 (FoFo                *fo_node,
   new_area = fo_area_area_new ();
   use_parent_area = context->parent_area;
 
-  FO_AREA (new_area)->generated_by = fo_node;
+  fo_area_set_generated_by (FO_AREA (new_area), fo_node);
   FO_FO (fo_node)->areas = g_list_append (FO_FO (fo_node)->areas, new_area);
   fo_area_add_child (use_parent_area, new_area);
   new_area = fo_area_size_request (new_area);
